#!/bin/sh

#usage rc-file conf-file uid data_path

group=`id -gn $3`

cp $1 /etc/rc.d/minkowsky
cp $2 /etc/minkowsky
chown $3 /etc/minkowsky
chgrp $group /etc/minkowsky
chmod a+r /etc/minkowsky
chmod u+rx /etc/rc.d/minkowsky

if [ -s /sbin/insserv ] 
then
    /sbin/insserv -r /etc/rc.d/minkowsky
    /sbin/insserv /etc/rc.d/minkowsky
else
    if [ -s /usr/sbin/insserv ] 
    then
	/usr/sbin/insserv -r /etc/rc.d/minkowsky
	/usr/sbin/insserv /etc/rc.d/minkowsky
    else
	echo "Please add /etc/rc.d/minkowsky to the appropriate runlevels"i
    fi
fi

if [ ! -d $4 ]
then
    mkdirhier $4
fi
if [ ! -d $5 ]
then
    mkdirhier $5
fi
chown $3 $4 $5
